@@ -31,6 +31,7 @@ typedef struct _GdkPixbufLoader GdkPixbufLoader;
 namespace KMPlayer {
 
 class Control;
+class ImageData;
 
 
 /*
@@ -38,14 +39,12 @@ class Control;
  */
 class KMPLAYER_EXPORT ActorAgent {
 public:
-    enum ActorType { Audio, AudioVideo, Image, Text };
+    enum ActorType { Any, Audio, AudioVideo, Image, Text };
     //typedef QValueList <Actor *> MediaList;
 
     ActorAgent (Control *ctrl);
     ~ActorAgent ();
 
-    Actor *hire (ActorType type, Node *node);
-
     //MediaList &medias () { return m_media_objects; }
     Control *control () const { return m_control; }
 
@@ -61,7 +60,7 @@ private:
  * Abstract base of Actor types, handles downloading
  */
 
-class KMPLAYER_EXPORT Actor : public AsyncJobInterface {
+class KMPLAYER_EXPORT Actor {
     friend class ActorAgent;
 public:
     virtual ActorAgent::ActorType type () const = 0;
@@ -72,30 +71,45 @@ public:
     virtual void stop () {}
     /*virtual*/ void dismiss ();
 
-    virtual bool wget (const String &url);
-    void killWGet ();
-    void clearData ();
-    String mimetype ();
-    bool downloading () const;
-
     Mrl *mrl ();
-    ByteArray &rawData () { return data; }
-
-private:
-    virtual void jobData (Job *job, ByteArray &data);
-    virtual void jobResult (Job *job);
 
 protected:
     Actor (ActorAgent *manager, Node *node);
     virtual ~Actor ();
 
-    virtual void ready (const String &url);
-
     ActorAgent *m_agent;
     NodePtrW m_node;
+};
+
+//------------------------%<----------------------------------------------------
+
+class KMPLAYER_EXPORT MediaInfo : public AsyncJobInterface {
+public:
+    MediaInfo (Node *node, ActorAgent::ActorType type);
+    ~MediaInfo ();
+
+    bool wget (const String &url);
+    void killWGet ();
+    void clearData ();
+    String mimetype ();
+    bool downloading () const;
+    void create ();
+
+    ByteArray &rawData () { return data; }
+    Actor *media;
     String url;
     ByteArray data;
     String mime;
+    ActorAgent::ActorType type;
+
+private:
+    virtual void jobData (Job *job, ByteArray &data);
+    virtual void jobResult (Job *job);
+
+    void ready ();
+    bool readChildDoc ();
+
+    Node *node;
     Job *job;
 };
 
@@ -160,7 +174,9 @@ typedef WeakPtr <ImageData> ImageDataPtrW;
 
 class KMPLAYER_NO_EXPORT ImageActor : public Actor {
 public:
-    ImageActor (ActorAgent *manager, Node *node);
+    ImageActor (ActorAgent *manager, Node *node,
+            const String &url, const ByteArray &data);
+    ImageActor (Node *node, ImageDataPtr id);
 
     ActorAgent::ActorType type () const { return ActorAgent::Image; }
 
@@ -169,7 +185,6 @@ public:
     void pause ();
     void unpause ();
 
-    bool wget (const String &url);
     bool isEmpty () const;
     bool movieTimer ();
 
@@ -178,10 +193,8 @@ public:
 protected:
     ~ImageActor ();
 
-    void ready (const String &url);
-
 private:
-    void setupImage ();
+    void setupImage (const String &url, const ByteArray &ba);
 
     GdkPixbufAnimation *img_movie;
     GdkPixbufAnimationIter *img_movie_iter;
@@ -197,19 +210,17 @@ private:
  */
 class KMPLAYER_NO_EXPORT TextActor : public Actor {
 public:
-    TextActor (ActorAgent *manager, Node *node);
+    TextActor (ActorAgent *manager, Node *node, const ByteArray &ba);
 
     ActorAgent::ActorType type () const { return ActorAgent::Text; }
 
     bool play ();
 
     String text;
-    int default_font_size;
+    static int defaultFontSize ();
 
 protected:
     ~TextActor ();
-
-    void ready (const String &url);
 };
 
 } // namespace
