@@ -399,7 +399,6 @@ static void create_menu (Application * app) {
     GtkWidget *menu_playlist;
     GtkWidget *menu_players;
     GtkWidget *item_close;
-    GtkWidget *item_separator;
     GtkWidget *item_playlist;
     GtkWidget *item_playlist_show;
     GtkWidget *item_players;
@@ -426,14 +425,15 @@ static void create_menu (Application * app) {
     app->menu_item_playlist_showall = gtk_check_menu_item_new_with_label ("Show All");
     app->menu_item_playlist_edit = gtk_check_menu_item_new_with_label ("Edit");
     item_close = gtk_menu_item_new_with_label ("Close");
-    item_separator = gtk_separator_menu_item_new ();
     item_players = gtk_menu_item_new_with_label ("Player");
     app->menu_item_media_server = gtk_radio_menu_item_new_with_label (NULL, "Osso Media Server");
     app->menu_item_mplayer = gtk_radio_menu_item_new_with_label_from_widget(
             GTK_RADIO_MENU_ITEM (app->menu_item_media_server), "MPlayer");
     app->menu_item_npp = gtk_radio_menu_item_new_with_label_from_widget(
             GTK_RADIO_MENU_ITEM (app->menu_item_media_server), "Flash");
-    
+    app->menu_item_mplayer_vo = gtk_check_menu_item_new_with_label(
+            "Use omapfb with MPlayer");
+
     /* Add menu items to right menus */
     gtk_menu_append (main_menu, item_new);
     gtk_menu_append (main_menu, item_open);
@@ -445,12 +445,14 @@ static void create_menu (Application * app) {
     gtk_menu_append (menu_playlist, app->menu_item_playlist_paste);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_paste_in_group);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_cut);
-    gtk_menu_append (menu_playlist, item_separator);
+    gtk_menu_append (menu_playlist, gtk_separator_menu_item_new ());
     gtk_menu_append (menu_playlist, app->menu_item_playlist_showall);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_edit);
     gtk_menu_append (menu_players, app->menu_item_media_server);
     gtk_menu_append (menu_players, app->menu_item_mplayer);
     gtk_menu_append (menu_players, app->menu_item_npp);
+    gtk_menu_append (menu_players, gtk_separator_menu_item_new ());
+    gtk_menu_append (menu_players, app->menu_item_mplayer_vo);
     gtk_menu_append( main_menu, item_close );
 
     /* Add others submenu to the "Others" item */
@@ -490,6 +492,8 @@ static void create_menu (Application * app) {
         GTK_SIGNAL_FUNC (toggleMediaServer), app);
     g_signal_connect (G_OBJECT (app->menu_item_npp), "toggled",
         GTK_SIGNAL_FUNC (toggleMediaServer), app);
+    g_signal_connect (G_OBJECT (app->menu_item_mplayer_vo), "toggled",
+        GTK_SIGNAL_FUNC (toggleVO), app);
 
     g_signal_connect (G_OBJECT (main_menu), "show",
         GTK_SIGNAL_FUNC (mainMenuShow), app);
