@@ -124,7 +124,7 @@ void cb_playlist_prev (GtkButton * button, void *ctr);
 void cb_playlist_play (GtkButton * button, void *ctr);
 void cb_playlist_next (GtkButton * button, void *ctr);
 void cb_playlist_stop (GtkButton * button, void *ctr);
-GValue *playlist_selected (Application *app, GValue *value);
+gboolean playlist_selected (Application *app, GValue *icon, GValue *text);
 void cb_favorites_add (Application *app);
 void progressValueChanged(GtkWidget *w, Application * app);
 gboolean cb_scheduledPaint (void * p);
