@@ -43,7 +43,7 @@ public:
     Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "feed"; }
     void closed ();
-    bool expose () const { return !pretty_name.isEmpty (); }
+    bool expose () const { return !caption.isEmpty (); }
 };
 
 class KMPLAYER_NO_EXPORT Entry : public Mrl {
