@@ -254,7 +254,9 @@ KDE_NO_EXPORT void PlaylistItem::setNodeName (const String & s) {
 
 KDE_NO_CDTOR_EXPORT
 PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr & doc, Application * a, const String & pn)
-  : KMPlayer::Mrl (doc, KMPlayer::id_node_group_node), app (a), playmode (false) {
+ : KMPlayer::Element (doc, KMPlayer::id_node_group_node),
+   app (a),
+   playmode (false) {
     caption = pn;
     if (!pn.isEmpty ())
         setAttribute (KMPlayer::StringPool::attr_title, pn);
@@ -262,7 +264,9 @@ PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr & doc, Application * a, const St
 
 KDE_NO_CDTOR_EXPORT
 PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr & doc, Application * a, bool lm)
-  : KMPlayer::Mrl (doc, KMPlayer::id_node_group_node), app (a), playmode (lm) {
+ : KMPlayer::Element (doc, KMPlayer::id_node_group_node),
+   app (a),
+   playmode (lm) {
 }
 
 KDE_NO_EXPORT KMPlayer::Node *PlaylistGroup::childFromTag (const String & tag) {
