@@ -147,7 +147,7 @@ void Control::init () {
     pldoc->path = tmp;
     m_app->playlists_tree_id = addTree (m_app, playlists,
             gtk_icon_theme_load_icon(icon_theme,
-                "qgn_list_gene_playlist", 26, (GtkIconLookupFlags)0, 0L));
+                "kmplayer-fav", 26, (GtkIconLookupFlags)0, 0L));
     GConfClient *client = (GConfClient *)(GConf &) *m_config;
     GSList *plists = gconf_client_all_entries (client, GCONF_KEY_LISTS, NULL );
     for (GSList *elm = plists; elm; elm = elm->next) {
@@ -627,8 +627,9 @@ void Control::updatePlaylistView (bool force) {
             update_tree_timer = 0;
         }
         updateTree (m_app, 0);
-    } else if (!update_tree_timer)
+    } else if (!update_tree_timer) {
         update_tree_timer = g_timeout_add (200, cb_scheduledUpdateTree, this);
+    }
 }
 
 static const char * statemap [] = {
@@ -965,6 +966,8 @@ void cb_favorites_add (Application *app) {
             if (fav && valid) {
                 msg = "Added to favorites";
                 NodePtr doc = mrl->document ();
+                if (!fav->document->mrl ()->resolved)
+                    fav->document->activate (); // lazy load playlist
                 NodePtr n;
                 if (id_node_playlist_item == mrl->id) {
                     n = mrl;
@@ -975,6 +978,8 @@ void cb_favorites_add (Application *app) {
                 String xml = n->outerXML ();
                 TextStream inxml ((const char *) xml);
                 readXML (fav->document, inxml, String(), false);
+                if (fav->document->lastChild ())
+                    fav->document->lastChild ()->normalize ();
                 updateTree (app, fav->id);
             }
         }
@@ -1070,7 +1075,8 @@ gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app) {
                 CONTROL(app)->process ()->seek (200, false); // 20s
             break;
         case GDK_Return: // HILDON_HARDKEY_SELECT
-            rowSelected (app);
+            if (app->fullscreen)
+                rowSelected (app);
             break;
         case GDK_Up:
             if (app->fullscreen)
