@@ -52,20 +52,10 @@ struct MAEMO_NO_EXPORT PlayListData {
 };
 
 
-class MAEMO_NO_EXPORT Control : public PlayListNotify, public ProcessNotify, public AsyncJobInterface {
+class MAEMO_NO_EXPORT Control : public PlayListNotify, public ProcessNotify {
     Process * m_process;
     Rect video_rect;
     int m_doc_timer;
-    struct ResolveInfo {
-        ResolveInfo (NodePtr mrl, Job * j, SharedPtr <ResolveInfo> & n)
-            : resolving_mrl (mrl), job (j), next (n) {}
-        NodePtrW resolving_mrl;
-        Job * job;
-        //ByteArray data;
-        TextStream data;
-        SharedPtr <ResolveInfo> next;
-    };
-    SharedPtr <ResolveInfo> m_resolve_info;
     GtkWidget *progress_banner;
 public:
     Control (Application * a);
@@ -77,7 +67,6 @@ public:
     void openDocument (NodePtr doc, NodePtr cur);
     void playCurrent ();
     String currentMrl ();
-    void readPlaylist (NodePtr root, TextStream & in);
     void updatePlaylistView (bool force=false);
     ViewArea *viewArea () const;
     unsigned long videoOutput () const;
@@ -88,7 +77,6 @@ public:
      */
     ActorAgent *actorAgent () const;
     bool requestPlayURL (NodePtr mrl);
-    bool resolveURL (NodePtr mrl);
     bool setCurrent (NodePtr);
     bool applyBackRequest();
     void stateElementChanged (Node * n, Node::State os, Node::State ns);
@@ -142,8 +130,6 @@ public:
     bool in_progress_update;
     bool request_download;
 private:
-    virtual void jobData (Job * job, ByteArray & data);
-    virtual void jobResult (Job * job);
     ActorAgent *actor_agent;
     NodeList extra_playlists;
 };
