@@ -605,15 +605,15 @@ static bool hasMrlChildren (const NodePtr & e) {
 
 Mrl::Mrl (NodePtr & d, short id)
     : Element (d, id), cached_ismrl_version (~0),
-      actor (NULL),
+      media_info (NULL),
       aspect (0), repeat (0),
       view_mode (SingleMode),
       resolved (false), bookmarkable (true),
       audio_only (false) {}
 
 Mrl::~Mrl () {
-    if (actor)
-        actor->dismiss ();
+    if (media_info)
+        delete media_info;
 }
 
 Node::PlayType Mrl::playType () {
@@ -626,8 +626,11 @@ Node::PlayType Mrl::playType () {
 }
 
 String Mrl::absolutePath () {
+    int p = src.indexOf (":/");
+    if (p > -1 && p < 15)
+        return src;
     String path = src;
-    if (!path.isEmpty()) {
+    if (!path.isEmpty() && !path.startsWith ("tv:/")) {
         for (NodePtr e = parentNode (); e; e = e->parentNode ()) {
             Mrl * mrl = e->mrl ();
             if (mrl && !mrl->src.isEmpty () && mrl->src != src) {
@@ -656,6 +659,18 @@ Mrl * Mrl::mrl () {
 
 void *Mrl::message (MessageType msg, void *content) {
     switch (msg) {
+    case MsgMediaReady:
+        linkNode ()->resolved = true;
+        if (state == state_deferred) {
+            if (isPlayable ()) {
+                setState (state_activated);
+                begin ();
+            } else {
+                Element::activate ();
+            }
+        }
+        break;
+
     case MsgMediaFinished:
         if (state == state_deferred &&
                 !isPlayable () && firstChild ()) {//if backend added child links
@@ -664,60 +679,61 @@ void *Mrl::message (MessageType msg, void *content) {
         } else
             finish ();
         return NULL;
+
     case MsgQueryRoleChildDisplay:
         for (NodePtr p = parentNode (); p; p = p->parentNode ())
             if (p->mrl ())
                 return p->message (msg, content);
         return NULL;
+
+    default:
+        break;
     }
     return Node::message (msg, content);
 }
 
 void Mrl::activate () {
     resolved |= linkNode ()->resolved;
-    if (!resolved && document ()->notify_listener)
-        resolved = document ()->notify_listener->resolveURL (this);
-    if (!resolved) {
+    if (!resolved && linkNode () == this && isPlayable ()) {
         setState (state_deferred);
-        return;
-    } else
-        linkNode ()->resolved = true;
-    if (!isPlayable ()) {
+        media_info = new MediaInfo (this, ActorAgent::AudioVideo);
+        resolved = media_info->wget (absolutePath ());
+    } else if (isPlayable ()) {
+        setState (state_activated);
+        begin ();
+    } else {
         Element::activate ();
-        return;
     }
-    setState (state_activated);
-    begin ();
 }
 
 void Mrl::begin () {
-    //kdDebug () << nodeName () << " Mrl::activate" << endl;
-    if (document ()->notify_listener) {
-        if (linkNode () != this) {
-            linkNode ()->activate ();
-            if (linkNode ()->unfinished ())
-                setState (state_began);
-        } else if (!src.isEmpty ()) {
-            if (!actor)
-                actor = document ()->notify_listener->actorAgent()->hire (ActorAgent::AudioVideo, this);
-            if (actor->play ())
-                setState (state_began);
-            else
-                deactivate ();
-        } else
-            deactivate (); // nothing to activate
+    if (linkNode () != this) {
+        linkNode ()->activate ();
+        if (linkNode ()->unfinished ())
+            setState (state_began);
+    } else if (!src.isEmpty ()) {
+        if (!media_info)
+            media_info = new MediaInfo (this, ActorAgent::AudioVideo);
+        if (!media_info->media)
+            media_info->create ();
+        if (media_info->media->play ())
+            setState (state_began);
+        else
+            deactivate ();
+    } else {
+        deactivate (); // nothing to activate
     }
 }
 
 void Mrl::defer () {
-    if (actor)
-        actor->pause ();
+    if (media_info && media_info->media)
+        media_info->media->pause ();
     Node::defer ();
 }
 
 void Mrl::undefer () {
-    if (actor) {
-        actor->unpause ();
+    if (media_info && media_info->media) {
+        media_info->media->unpause ();
         setState (state_began);
     } else {
         Node::undefer ();
@@ -725,9 +741,9 @@ void Mrl::undefer () {
 }
 
 void Mrl::deactivate () {
-    if (actor) {
-        actor->dismiss ();
-        actor = NULL;
+    if (media_info) {
+        delete media_info;
+        media_info = NULL;
     }
     Node::deactivate ();
 }
