@@ -41,8 +41,7 @@ class Mrl;
 class Surface;
 class ElementPrivate;
 class Visitor;
-class ActorAgent;
-class Actor;
+class MediaInfo;
 
 /*
  * Base class for objects that will be used as SharedPtr/WeakPtr pointers.
@@ -238,6 +237,7 @@ enum MessageType
     MsgChildFinished,
 
     MsgStartQueryMessage,
+    MsgQueryActorAgent,
     MsgQueryRoleTiming,
     MsgQueryRoleDisplay,
     MsgQueryRoleChildDisplay,    // Mrl*
@@ -547,7 +547,7 @@ public:
      * location in SCR. Typically that's the parent of this node.
      */
     NodePtrW opener; //if this node is top node of external document,
-    Actor *actor;
+    MediaInfo *media_info;
     String src;
     String mimetype;
     Single width;
@@ -567,11 +567,6 @@ class KMPLAYER_EXPORT PlayListNotify {
 public:
     virtual ~PlayListNotify () {}
 
-    virtual ActorAgent *actorAgent () const = 0;
-    /**
-     * Called by an unresolved Mrl, check if this node points to a playlist
-     */
-    virtual bool resolveURL (NodePtr mrl) = 0;
     /**
      * Element has activated or deactivated notification
      */
@@ -749,6 +744,7 @@ namespace SMIL {
     class Layout;
     class RegionBase;
     class Seq;
+    class Switch;
     class Par;
     class Excl;
     class Transition;
@@ -758,7 +754,6 @@ namespace SMIL {
     class ImageMediaType;
     class TextMediaType;
     class RefMediaType;
-    class AVMediaType;
     class Brush;
     class SmilText;
     class TextFlow;
@@ -788,6 +783,7 @@ public:
     virtual void visit (SMIL::Layout *);
     virtual void visit (SMIL::RegionBase *);
     virtual void visit (SMIL::Seq *);
+    virtual void visit (SMIL::Switch *);
     virtual void visit (SMIL::Par *);
     virtual void visit (SMIL::Excl *);
     virtual void visit (SMIL::Transition *);
@@ -798,7 +794,6 @@ public:
     virtual void visit (SMIL::ImageMediaType *);
     virtual void visit (SMIL::TextMediaType *);
     virtual void visit (SMIL::RefMediaType *);
-    virtual void visit (SMIL::AVMediaType *);
     virtual void visit (SMIL::Brush *);
     virtual void visit (SMIL::SmilText *);
     virtual void visit (SMIL::TextFlow *);
