@@ -285,10 +285,6 @@ void KMPlayer::updateTree (Application * app, short id) {
 
     } else {
 
-        g_object_ref (model);
-
-        gtk_tree_view_set_model (treeview, NULL); //detach
-
         valid_tree = gtk_tree_store_remove (GTK_TREE_STORE (model), &oldriter);
         if (valid_tree)
             gtk_tree_store_insert_before(GTK_TREE_STORE(model),&riter,0L,&oldriter);
@@ -297,7 +293,6 @@ void KMPlayer::updateTree (Application * app, short id) {
         rpath = gtk_tree_model_get_path (model, &riter);
         populate (GTK_TREE_STORE (model), pld,
                 pld->document, &riter, 0L, &fpath);
-        gtk_tree_view_set_model (treeview, model);//attach
         if (!fpath)
             fpath = rpath;
         else
@@ -305,12 +300,12 @@ void KMPlayer::updateTree (Application * app, short id) {
 
         while (!gtk_tree_model_get_iter (model, &valid_iter, fpath) &&
                 gtk_tree_path_up (fpath));
-
-        g_object_unref (model);
     }
 
     if (fpath) {
-        gtk_tree_view_expand_to_path (treeview, fpath);
+        if (gtk_tree_path_get_depth (fpath) > 1)
+            gtk_tree_view_expand_to_path (treeview, fpath);
+
         gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), fpath);
         gtk_tree_view_scroll_to_cell (treeview, fpath, NULL, false, 0, 0);
         gtk_tree_path_free (fpath);
@@ -454,15 +449,16 @@ gboolean cb_treeViewClicked (GtkWidget *view, GdkEventButton *evt, Application *
                 gtk_tree_model_get_iter (model, &iter, path);
                 need_update = !gtk_tree_model_iter_has_child (model, &iter);
             }
-            if ( need_update) {
+            if (need_update) {
                 pld->updated_document = NULL;
                 updateTree (app, pld->id);
                 gtk_tree_model_get_iter (model, &iter, path);
                 if (gtk_tree_model_iter_has_child (model, &iter)) {
-                    if (!gtk_tree_view_row_expanded (tree_view, path))
-                        gtk_tree_view_expand_row (tree_view, path, FALSE);
-                    else
+                    if (!gtk_tree_view_row_expanded (tree_view, path)) {
+                        gtk_tree_view_expand_to_path (tree_view, path);
+                    } else {
                         gtk_tree_view_collapse_row (tree_view, path);
+                    }
                 }
             }
         }
@@ -518,18 +514,54 @@ void cb_row_activated (GtkTreeView * tree_view, GtkTreePath *path,
         jump (node.ptr (), CONTROL(app));
 }
 
-void KMPlayer::rowSelected (Application * app) {
-    GtkTreePath *path;
-    PlayListData * pld = getListDataFromSelection (app, &path);
+void KMPlayer::rowSelected (Application *app) {
+    GtkTreeIter iter;
+    GtkTreeView *view = GTK_TREE_VIEW (app->playlist_view);
+    GtkTreeSelection *sel = gtk_tree_view_get_selection (view);
+    GtkTreeModel *model = gtk_tree_view_get_model (view);
+    bool expand_collapse = false;
+    NodePtr node;
+
     debugLog() << "row selected" << endl;
-    if (!pld || gtk_tree_path_get_depth (path) == 1)
-        return; // handled by clicked
-    NodePtr node = getNode (pld, path);
-    app_set_info_content (app, node
-            ? (pld->edit_mode ? node->innerXML () : node->innerText ())
-            : "", pld->edit_mode);
-    if (!pld->edit_mode && (pld->id == 0 || node->mrl ()))
-        jump (node.ptr (), CONTROL(app));
+    if (!gtk_tree_selection_get_selected (sel, 0L, &iter))
+        return;
+
+    PlayListData *pld = getListData (app, model, &iter);
+    if (!pld)
+        return;
+
+    GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
+    if (gtk_tree_path_get_depth (path) == 1) {
+        expand_collapse = true;
+        if (pld->id && !gtk_tree_model_iter_has_child (model, &iter)) {
+            pld->document->activate (); //enable lazy loading
+            if (!pld->document->isPlayable ())
+                updateTree (app, pld->id);
+        }
+    } else {
+        node = getNode (pld, path);
+        if (node && node->id == id_node_group_node)
+            expand_collapse = true;
+    }
+    if (expand_collapse) {
+        if (gtk_tree_model_iter_has_child (model, &iter)) {
+            if (!gtk_tree_view_row_expanded (view, path)) {
+                GtkTreeIter next;
+                gtk_tree_view_expand_row (view, path, FALSE);
+                if (gtk_tree_model_iter_children (model, &next, &iter))
+                    gtk_tree_selection_select_iter (sel, &next);
+            } else {
+                gtk_tree_view_collapse_row (view, path);
+            }
+        }
+    } else {
+        app_set_info_content (app, node
+                ? (pld->edit_mode ? node->innerXML () : node->innerText ())
+                : "", pld->edit_mode);
+        if (!pld->edit_mode && (pld->id == 0 || node->mrl ()))
+            jump (node.ptr (), CONTROL(app));
+    }
+    gtk_tree_path_free (path);
 }
 
 void KMPlayer::nextSelected (Application *app) {
@@ -540,11 +572,9 @@ void KMPlayer::nextSelected (Application *app) {
     GtkTreeModel *model = gtk_tree_view_get_model (view);
 
     if (gtk_tree_selection_get_selected (selection, NULL, &iter)) {
-        if (gtk_tree_model_iter_has_child (model, &iter)) {
-            GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
-            if (!gtk_tree_view_row_expanded (view, path))
-                gtk_tree_view_expand_row (view, path, FALSE);
-            gtk_tree_path_free (path);
+        GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
+        if (gtk_tree_model_iter_has_child (model, &iter) &&
+            gtk_tree_view_row_expanded (view, path)) {
             if (gtk_tree_model_iter_children (model, &next, &iter))
                 gtk_tree_selection_select_iter (selection, &next);
         } else if (gtk_tree_model_iter_next (model, &iter)) {
@@ -558,6 +588,7 @@ void KMPlayer::nextSelected (Application *app) {
                 iter = next;
             }
         }
+        gtk_tree_path_free (path);
     }
 }
 
@@ -577,17 +608,18 @@ void KMPlayer::previousSelected (Application *app) {
     }
 }
 
-GValue *playlist_selected (Application *app, GValue *value) {
+gboolean playlist_selected (Application *app, GValue *icon, GValue *text) {
     GtkTreeIter iter;
     GtkTreeView *view = GTK_TREE_VIEW (app->playlist_view);
     GtkTreeSelection *selection = gtk_tree_view_get_selection (view);
     GtkTreeModel *model = gtk_tree_view_get_model (view);
 
     if (gtk_tree_selection_get_selected (selection, NULL, &iter)) {
-        gtk_tree_model_get_value (model, &iter, COL_TEXT, value);
-        return value;
+        gtk_tree_model_get_value (model, &iter, COL_ICON, icon);
+        gtk_tree_model_get_value (model, &iter, COL_TEXT, text);
+        return true;
     }
-    return NULL;
+    return false;
 }
 
 void cb_treeCellDataFunc (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell,
