@@ -2004,13 +2004,21 @@ GdkFilterReturn controlsFilter (GdkXEvent *xe, GdkEvent *e, Application *app) {
             cairo_set_source_rgb (cr, 32.0 / 255, 1, 48.0 / 255);
             cairo_rectangle (cr, 655, 0, 50, 60);
             cairo_fill (cr);
-            GValue value = { 0 , };
-            if (playlist_selected (app, &value)) {
-                const gchar *val = g_value_get_string (&value);
+            GValue icon = { 0 , };
+            GValue text = { 0 , };
+            if (playlist_selected (app, &icon, &text)) {
+                GdkPixbuf *pix = (GdkPixbuf *) g_value_get_object (&icon);
+                const gchar *val = g_value_get_string (&text);
+                int pixw = gdk_pixbuf_get_width (pix);
+                cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
+                gdk_cairo_set_source_pixbuf (cr, pix, 127, 17);
+                cairo_rectangle (cr, 127, 17, pixw, pixw);
+                cairo_fill (cr);
+                cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
                 cairo_set_source_rgb (cr, 0.8, 0.8, 0);
-                cairo_move_to (cr, 130, 10);
+                cairo_move_to (cr, 157, 10);
                 PangoLayout *layout = pango_cairo_create_layout (cr);
-                pango_layout_set_width (layout, 510 * PANGO_SCALE);
+                pango_layout_set_width (layout, 483 * PANGO_SCALE);
                 pango_layout_set_text (layout, val, -1);
                 PangoFontDescription *desc = pango_font_description_new ();
                 pango_font_description_set_family (desc, "Sans");
@@ -2020,7 +2028,8 @@ GdkFilterReturn controlsFilter (GdkXEvent *xe, GdkEvent *e, Application *app) {
                 pango_font_description_free (desc);
                 pango_cairo_show_layout (cr, layout);
                 g_object_unref (layout);
-                g_value_unset (&value);
+                g_value_unset (&icon);
+                g_value_unset (&text);
             }
             cairo_destroy (cr);
             return GDK_FILTER_REMOVE;
